C----------------------------------------------------------------------
C
C  TELL
C
C  WRITE RESULTS
C
C----------------------------------------------------------------------
      SUBROUTINE TELL (D1,D2)
      INTEGER D1,D2
C
C  THE DATA ARE IN COMMON OUT  
C
      INTEGER MAXOBJ, MAXDAY, MMM, ORDER
      PARAMETER (MAXOBJ=10, MAXDAY=10000, ORDER=7, MMM=3)
      REAL
     .    PLANET(3,MAXOBJ),      
     .    OLDPL(2,MAXOBJ)    
      INTEGER
     .    TODAY
      REAL
     .    OUTBUF(MAXDAY,3,MAXOBJ)      
C
      COMMON /OUT/ OUTBUF, PLANET, OLDPL, TODAY
C
C
      INTEGER I,DAY,ND,Y,M,D,WD,K
      CHARACTER*10 NAME(10)
      DATA NAME /'SUN       ',
     .           '          ',
     .           'MERCURY   ',
     .           'VENUS     ',
     .           'MARS      ',
     .           'JUPITER   ',
     .           'SATURN    ',
     .           'URANUS    ',
     .           'NEPTUNE   ',
     .           'PLUTO     ' /
C
      ND=D2-D1
      DO 11 I=1,7,2
         WRITE(*,'('' '',A10)') NAME(I)
         DO 10 DAY=D1,D2,1000
            K=DAY-D1+1
            CALL GREGOR(DAY,Y,M,D,WD)
            WRITE(*,'('' '',I2,''.'',I2,''.'',I4,
     .                '' R.A. = '',F8.3,''  DEC = '',F8.3,
     .                ''  DIST = '',F8.3)')
     .           D,M,Y,     
     .           OUTBUF(K,1,I),OUTBUF(K,2,I),OUTBUF(K,3,I)
 10      CONTINUE
 11   CONTINUE
      RETURN
      END
