      SUBROUTINE ECHECK(A,ZK,YK,N,EIGV)
CDEP  
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      DIMENSION A(N,N),ZK(N),YK(N)
      EXTERNAL DOTVEC
C     
      CALL MATVEC(A,ZK,N,YK)
      CALL ADDVEC(YK,ZK,N,-EIGV,YK)
      VECLEN=DSQRT(DOTVEC(YK,YK,N))
      WRITE(6,*)'**ECHECK:  RESIDUAL VECTOR LENGTH=',VECLEN
      WRITE(6,*)
      END
