      SUBROUTINE COPY (N, A, B)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
C
C   ARRAY COPY ROUTINE
C
      DIMENSION A(N), B(N)
      DO 100 I = 1, N
        B(I) = A(I)
100   CONTINUE
      RETURN
      END
