      SUBROUTINE ECOORD (NELE,GEOM,IGEOM,ELTOP,IELTOP,COORD,ICOORD)
      INTEGER NELE, IGEOM, IELTOP, ELTOP(IELTOP,*), ICOORD
      DOUBLE PRECISION GEOM(IGEOM,*), COORD(ICOORD,*)
      INTEGER J, NODE

      DO 100 J=1,ELTOP(2,NELE)  
         NODE = ELTOP(2+J,NELE)
         GEOM(J,1) = COORD(1,NODE)
         GEOM(J,2) = COORD(2,NODE)
100   CONTINUE
      RETURN
      END
