C     *****************
      SUBROUTINE ACCEPT(NVH,NVL,IACPT,WK4,WK3,WK2,WK1)
C     *****************

      DOUBLE PRECISION WK1(NVH,18), WK2(NVH,18),
     >                 WK3(NVH,18), WK4(NVH,18)

C     ACCEPT NEW LINK IF EXP(-S) > RANDOM NUMBER[0-1]

      DO 10 IVL = 1,NVL
      IF( WK4(IVL,1) .GT. WK2(IVL,1) ) THEN
          DO 20 ISM = 1,18
          WK1(IVL,ISM) = WK3(IVL,ISM)
   20     CONTINUE
          IACPT = IACPT + 1
      ENDIF
   10 CONTINUE
C
      END
