      SUBROUTINE MFILL (N1,N2,M,VAL)
      INTEGER N1,N2
      DOUBLE PRECISION M(N1,*), VAL
      INTEGER I,J
      DO 10 I=1,N1
         DO 10 J=1,N2
            M(I,J) = VAL
 10   CONTINUE
      RETURN
      END
