      SUBROUTINE MATNUL (A,NROWA,NCOLA)
      INTEGER NROWA, NCOLA
      DOUBLE PRECISION A(NROWA*NCOLA)
      INTEGER I
      DO 100 I=1,NROWA*NCOLA
         A(I) = 0.D0
 100  CONTINUE
      RETURN
      END
