C----------------------------------------------------------------------
C
C  A N T I B
C
C  THIS FAR WE HAVE COMPUTED THE ORBIT OF THE BARYCENTRE OF
C  THE EARTH-MOON SYSTEM; NOW MOVE THE ORIGIN TO THE CENTRE OF THE EARTH
C  AE S.E1 (1982), NOTE 6
C
C----------------------------------------------------------------------
      SUBROUTINE ANTIB(X,Y,Z,T)
      REAL
     .    X,Y,Z,T
C
C  CONSTANTS
C
      REAL  PI,PI2,CPI,DTORAD,RTODEG,
     .                  GRAVIT,OBLIQ
      COMMON /CONST/    PI,PI2,CPI,DTORAD,RTODEG,
     .                  GRAVIT,OBLIQ
C 
C
      REAL
     .    L,JC
C
      JC=T/36525.0E+0 
      L=AMOD (270+481268*JC,360.0E+0) * DTORAD
      X=X-0.0000312*COS(L)
      Y=Y-0.0000312*SIN(L)
      Z=Z
      RETURN
      END
