      SUBROUTINE CONVEL (NODEL,XVELO,YVELO,UPREV,STEER)
      INTEGER NODEL,STEER(*)
      DOUBLE PRECISION XVELO(*),YVELO(*),UPREV(*)
      INTEGER I

      DO 10 I=1,NODEL
        XVELO(I)=UPREV(2*STEER(I)-1)
        YVELO(I)=UPREV(2*STEER(I))
10    CONTINUE
      RETURN
      END
