      SUBROUTINE B2STOK (B,GDER,SF8X2,SFUN1,SFUN2,NODEL)
      INTEGER NODEL
      DOUBLE PRECISION B(4,2*NODEL),GDER(2,NODEL),SF8X2(2,2*NODEL),
     +     SFUN1(*),SFUN2(*)
      DOUBLE PRECISION ZERO
      PARAMETER (ZERO=0.D0)
      INTEGER DOFEL, J, JJ
      DOFEL = 2*NODEL
      CALL VFILL (4*DOFEL,B,ZERO)
      CALL VFILL (2*DOFEL,SF8X2,ZERO)

      DO 100 J=1,NODEL
         JJ = 2*J - 1
         B(1,JJ)   = GDER(1,J)
         B(2,JJ)   = GDER(2,J)
         B(3,JJ+1) = GDER(1,J)
         B(4,JJ+1) = GDER(2,J)

         SF8X2(1,JJ)=SFUN1(J)
         SF8X2(2,JJ+1)=SFUN2(J)

100   CONTINUE     
      RETURN
      END
