      SUBROUTINE MATPRT(A,N)
CDEP  
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      DIMENSION A(N,N)             
      CHARACTER FMT*17
      SAVE FMT
      DATA FMT/'(1P,(1X,10E13.5))'/
C     12345678901234567
c-old      NN=MIN(N,10)
      NN=MIN(N,6)
      WRITE(UNIT=FMT(9:10),FMT='(I2)') NN
C1000 FORMAT(1P,(1X,<NN>E13.5))            
      WRITE(6,FMT=FMT) ((A(I,J),J=1,NN),I=1,NN)
      END
