      SUBROUTINE MATRAN (A,AT,NROWA,NCOLA)
      INTEGER NROWA, NCOLA
      DOUBLE PRECISION A(NROWA,NCOLA), AT(NCOLA,NROWA)
      INTEGER I, J
      DO 110 I=1,NROWA
         DO 100 J=1,NCOLA
            AT(J,I) = A(I,J)
100      CONTINUE
110   CONTINUE
      RETURN
      END
