      SUBROUTINE ASMBTE(A,ALOK,MLOK,F,FLOK,MXNOD,STEER,NODEL,
     +                IDIAG)

      INTEGER MXNOD,NODEL,IDIAG,STEER(*)
      DOUBLE PRECISION A(MXNOD,*),F(*),ALOK(NODEL,*),MLOK(NODEL,*),
     +     FLOK(*)
      INTEGER INDI,INDJ,I,J

        DO 10 I=1,NODEL
          DO 20 J=1,NODEL
            INDI=STEER(I)
            INDJ=STEER(J)
            INDJ=IDIAG+INDJ-INDI
            A(INDI,INDJ)=A(INDI,INDJ)+ALOK(I,J)
            A(INDI,INDJ)=A(INDI,INDJ)+MLOK(I,J)
 20      CONTINUE
         F(STEER(I))=F(STEER(I))+FLOK(I)
 10   CONTINUE

      RETURN
      END
