      SUBROUTINE GETSCR(IUN,A,N,M)
CDEP  
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      DIMENSION A(N,M)
c--   version 3
      REWIND IUN
      DO 100 J=1,M
         READ(IUN) (A(I,J),I=1,N)
 100  CONTINUE 
c--      do 100 j=1,m
c--         do 110 i=1,n
c--            a(i,j)=atmp(i,j)
c-- 110     continue
c-- 100  continue
      END
