      SUBROUTINE MATVEC(A,B,N,AB)
CDEP  
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      DIMENSION A(N,N),B(N),AB(N)
C     
      DO 100 I=1,N
         AB(I)=0.
 100  CONTINUE
C     
      DO 200 J=1,N
         BJ=B(J)
         DO 210 I=1,N
            AB(I)=AB(I)+A(I,J)*BJ
 210     CONTINUE
 200  CONTINUE
      END       
