      SUBROUTINE EIGVAL(IX,IY,JDIM,KDIM,Q,PRESS,SNDSP,XYJ,XY,TMET,
     *                   UU,CC)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
C
C  IX = 1  IY = 2 FOR XI   DIRECTION  METRICS
C  IX = 3  IY = 4 FOR ETA  DIRECTION  METRICS
C
      COMMON/BASE/
     1  JMAX,       KMAX,     JM,          KM,          JBEGIN,   JEND,
     1  KBEGIN,     KEND,     JPLUS(999),  JMINU (999), JLOW,     JUP,
     1  KLOW,       KUP,      PERIDC  ,    NP,          DT,   CP2TIM,
     1  FSMACH,     ALPHA,    GAMMA,       GAMI,        PI,
     1  DIS2X,      DIS2Y,    DIS4X,       DIS4Y,       PHIDT,    
     1  THETAD ,    RESID,    JACDT,       IPRINT,      NPCP,
     1  JTAIL1,     JTAIL2,   NUMITE ,     ISTART,      NSTEPS
      LOGICAL PERIDC  
      COMMON/GRID/DYM,YMAX,XMIN,XMAX,THICK
C
      DIMENSION Q(JDIM,KDIM,4),PRESS(JDIM,KDIM),SNDSP(JDIM,KDIM)
      DIMENSION XY(JDIM,KDIM,4)
      DIMENSION TMET(JDIM,KDIM),XYJ(JDIM,KDIM)
C
      DIMENSION UU(JDIM,KDIM),CC(JDIM,KDIM)
C
C   COMPUTE SPECTRAL RADIUS SCALING
C
      DO 100 K=KBEGIN,KEND
      DO 100 J=JBEGIN,JEND
C        RI IS J/RHO
         RI = 1./Q(J,K,1)
         U = Q(J,K,2)*RI
         V = Q(J,K,3)*RI
C
C  NOTE: TIME METRICS PUT IN (SLOPPY BUT THEY WORK)
C
         UU(J,K) = TMET(J,K) + U*XY(J,K,IX)+V*XY(J,K,IY)
         CC(J,K) = SNDSP(J,K)*SQRT(XY(J,K,IX)**2+XY(J,K,IY)**2)
C
  100 CONTINUE
C
                RETURN
                END
