C     ****************
      SUBROUTINE CHKIN(
C     ****************
     >                 NS,NT,NW1,
     >                 START,IAVG,IAVGDD,SEED,ITEMAX,
     >                 METHIT,ITBLUP,ORDEXP,BETA,SIGMA)
C
C
      INTEGER  SEED,START,ORDEXP
C
C
      DOUBLE PRECISION     BETA,SIGMA,
     >                     ZERO
C
C
      PARAMETER( ZERO = 0.D0 )
C
C
      IF( NS .LT. 2 .OR. NT .LT. 2 ) THEN
          WRITE(NW1,2000)
          STOP
      ENDIF
C
      NSC = NS  / 2
      NSC = NSC * 2
      NTC = NT  / 2
      NTC = NTC * 2
C
      IF( NSC .NE. NS .OR. NTC .NE. NT ) THEN
          WRITE(NW1,2010)
          STOP
      ENDIF
C
      IF( START. NE. 1 .AND. START .NE. 0 ) THEN
          WRITE(NW1,2050)
          STOP
      ENDIF
C
      IF( IAVG .LT. 1 ) THEN
          WRITE(NW1,2060)
          STOP
      ENDIF
C
      IF( IAVGDD .LT. 0 ) THEN
          WRITE(NW1,2070)
          STOP
      ENDIF
C
      IF( ITEMAX .LT. 0 ) THEN
          WRITE(NW1,2080)
          STOP
      ENDIF
C
      IF( METHIT .LT. 0 ) THEN
          WRITE(NW1,2090)
          STOP
      ENDIF
C
      IF( ITBLUP .LT. 0 ) THEN
          WRITE(NW1,2100)
          STOP
      ENDIF
C
      IF( ORDEXP .LT. 1 ) THEN
          WRITE(NW1,2100)
          STOP
      ENDIF
C
      IF( BETA .LE. ZERO ) THEN
          WRITE(NW1,2110)
          STOP
      ENDIF
C
      IF( SIGMA .LE. ZERO ) THEN
          WRITE(NW1,2120)
          STOP
      ENDIF
C
C
 2000 FORMAT(1X,'INPUT ERROR:'                                      /
     >       1X,'THE LINEAR LATTICE SIZE MUST BE GREATER THAN ONE,' /
     >       1X,'IN SPATIAL AND TEMPORAL DIMENSION'                 )
 2010 FORMAT(1X,'INPUT ERROR:'                                      /
     >       1X,'THE NUMBER OF LATTICE POINTS MUST BE EVEN,'        /
     >       1X,'IN SPATIAL AND TEMPORAL DIMENSION'                 )
 2020 FORMAT(1X,'INPUT ERROR:'                                      /
     >       1X,'THE NUMBER OF PROCESSES MUST BE GREATER THAN ZERO,'/
     >       1X,'IN EACH DIMENSION'                                 )
 2030 FORMAT(1X,'INPUT ERROR:'                                      /
     >       1X,'THE NUMBER OF PROCESSES MUST NOT BE GREATER THAN'  /
     >       1X,'THE NUMBER OF LATTICE POINTS FOR EACH DIMENSION'   )
 2040 FORMAT(1X,'INPUT ERROR:'                                      /
     >       1X,'PROVIDE THAT THE SUBLATTICE OF EACH PROCESS HAS'   /
     >       1X,'AT MOST ONE DIMENSION WITH A SINGLE LATTICE POINT' )
 2050 FORMAT(1X,'INPUT ERROR:'                                      /
     >       1X,'CHOOSE 0 FOR A DISORDERED START CONFIGURATION,'    /
     >       1X,'1 FOR AN ORDERED START CONFIGURATION'              )
 2060 FORMAT(1X,'INPUT ERROR:'                                      /
     >       1X,'THE MODUL FOR TAKING AVERAGES MUST BE GREATER THEN'/
     >       1X,'ONE'                                               )
 2070 FORMAT(1X,'INPUT ERROR:'                                      /
     >       1X,'THE NUMBER OF INITIALLY DISCARDED ITERATIONS'      /
     >       1X,'MUST NOT BE NEGATIVE'                              )
 2080 FORMAT(1X,'INPUT ERROR:'                                      /
     >       1X,'THE TOTAL NUMBER OF ITERATIONS MUST NOT BE'        /
     >       1X,'NEGATIVE'                                          )
 2090 FORMAT(1X,'INPUT ERROR:'                                      /
     >       1X,'THE NUMBER OF METROPOLIS-HITS MUST NOT BE NEGATIVE')
 2100 FORMAT(1X,'INPUT ERROR:'                                      /
     >       1X,'THE ORDER OF THE TAYLOR SERIES EXPANSION OF THE'   /
     >       1X,'OF THE EXPONENTIAL FUNCTION MUST BE GREATER THAN'  /
     >       1X,'ZERO'                                              )
 2110 FORMAT(1X,'INPUT ERROR:'                                      /
     >       1X,'THE BARE COUPLING CONSTANT MUST BE GREATER THEN'   /
     >       1X,'ZERO'                                              )
 2120 FORMAT(1X,'INPUT ERROR:'                                      /
     >       1X,'THE STANDARD DEVIATION FOR GAUSSIAN DISTRIBUTED'   /
     >       1X,'RANDOM NUMBERS MUST BE GREATER THAN ZERO'          )
C
C
      RETURN
      END
