      SUBROUTINE MESAGE(CHMESS,INDX,ISW)
C     
C..    A SUBROUTINE TO PRINT MESSAGE WHEN CPU_TIMER HAS BEEN
C     SWITCHED ON OR OFF
C     
      CHARACTER*20 CHMESS  
      WRITE(6,1000) CHMESS
 1000 FORMAT(/50X,'---> ',A20/)
      IF (ISW.EQ.1) CALL INITIM(INDX)
      IF (ISW.EQ.0) CALL SHOTIM(INDX)
      END
