      SUBROUTINE PARAM(NW1,NSTEP,NEQUIL,IPRINT,ISCALE,
     $                EQTEMP,DENS,RCUT,DT)

      WRITE(NW1,*)'     NUMBER OF STEPS           ',NSTEP
      WRITE(NW1,*)'     NUMBER OF EQUIL STEPS     ',NEQUIL
      WRITE(NW1,*)'     OUTPUT FREQUENCY          ',IPRINT
      WRITE(NW1,*)'     GLOBAL RESCALE FREQUENCY  ',ISCALE
      WRITE(NW1,*)'     TEMPERATURE               ',EQTEMP
      WRITE(NW1,*)'     DENSITY                   ',DENS
      WRITE(NW1,*)'     POTENTIAL CUTOFF          ',RCUT
      WRITE(NW1,*)'     TIMESTEP                  ',DT

      END
