C=======================================================================
C           Dimensional parameters and control parameters
C                 SI 8 atom unit cell
C
C   NEW PARAMETER - NIONCG (Recommended value is 1)
C
      IMPLICIT COMPLEX (C)
      PARAMETER(NGX=16,NGY=16,NGZ=16,
     &   NPLWV=NGX*NGY*NGZ,MPLWV=NGX*NGY*(NGZ+1),
     &   NPSPTS=2001,
     &   NRPLWV=4000,
     &   NEWPTS=1000,
     &   NIONS=2, NSPEC=2, NIONST=3,
     &   NRGRPT=1, MXRLNL=1, MXRLSH=1, NRLPTS=1,
     &   NBANDS=8, NBANOC=NBANDS,  NKPTS=1)
      PARAMETER (NDIM9=1,NDIM10=1)  ! Remember to change when using symmetry
C=======================================================================
C  THE FOLLOWING ARE PARAMETERS ORIGINALLY INSIDE SUBROUTINE EWLALTR.F
C=======================================================================
      PARAMETER(MAXCX=6, MAXCY=6, MAXCZ=6,
     &          MAXGPX=6,MAXGPY=6,MAXGPZ=6,
     &   NCELLX=(2*MAXCX)+1,NCELLY=(2*MAXCY)+1,NCELLZ=(2*MAXCZ)+1,
     &   NCELLS=NCELLX*NCELLY*NCELLZ,
     &   NGPTX=(2*MAXGPX)+1,NGPTY=(2*MAXGPY)+1,NGPTZ=(2*MAXGPZ)+1,
     &   NGPTS=NGPTX*NGPTY*NGPTZ)
C=====================================================================
