      SUBROUTINE ASRHS (RHS,ELF,STEER,DOFEL)
      INTEGER DOFEL, STEER(DOFEL)
      DOUBLE PRECISION RHS(*), ELF(*)
      INTEGER I, K
      DO 100 I=1,DOFEL
         K = STEER(I)
         IF (K.GT.0) RHS(K) = RHS(K) + ELF(I)
100   CONTINUE
      RETURN
      END
