C     *****************
      SUBROUTINE VDRAND(NVL,WK1)
C     *****************
C
C
      DOUBLE PRECISION WK1(NVL),
     >                 DRAND
C
C
      DO 10 I = 1,NVL
      WK1(I) = DRAND(0)
   10 CONTINUE
C
C
      RETURN
      END
C
C


