      SUBROUTINE SCALDT(JDIM,KDIM,S,DS)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
C
      COMMON/BASE/
     1  JMAX,       KMAX,     JM,          KM,          JBEGIN,   JEND,
     1  KBEGIN,     KEND,     JPLUS(999),  JMINU (999), JLOW,     JUP,
     1  KLOW,       KUP,      PERIDC  ,    NP,          DT,   CP2TIM,
     1  FSMACH,     ALPHA,    GAMMA,       GAMI,        PI,
     1  DIS2X,      DIS2Y,    DIS4X,       DIS4Y,       PHIDT,    
     1  THETAD ,    RESID,    JACDT,       IPRINT,      NPCP,
     1  JTAIL1,     JTAIL2,   NUMITE ,     ISTART,      NSTEPS
      LOGICAL PERIDC  
      COMMON/GRID/DYM,YMAX,XMIN,XMAX,THICK
C
      DIMENSION S(JDIM,KDIM,4),DS(JDIM,KDIM)
C
C
C  SCALE WITH SPATIALLY VARIABLE TIME STEP
C
      DO 10 M = 1,4
      DO 10 K = KBEGIN,KEND
      DO 10 J = JBEGIN,JEND
         S(J,K,M) = S(J,K,M)*DS(J,K)
10    CONTINUE
C
      RETURN
      END
