      SUBROUTINE READI(INPUT,A,B,N)
CDEP  
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      DIMENSION A(N,N),B(N)
C     
C-old      DO 100 J=1,N
C-old         READ(1,1000) (A(I,J),I=1,N)
C-old 100  CONTINUE          
      ZERO=0.0
      CALL COPVAL(A,N*N,ZERO)
 100  CONTINUE
      READ(INPUT,1000,END=110) 
     +     JCOL,IROW,NTERMS,(A(I,JCOL),I=IROW,IROW+NTERMS-1)
      GOTO 100
 110  CONTINUE
C-old      READ(1,1000) (B(I),I=1,N)
      DO 200 I=1,N
         B(I)=I
 200  CONTINUE
 1000 FORMAT(2I5,I3,5F13.0,:,/(6F13.0))
      END
