C----------------------------------------------------------------------
C
C   M O O N
C
C   COMPUTE LUNAR EPHEMERIS AT ONE HOUR INTERVALS FOR THE
C   POERIOD D1..D2
C
C----------------------------------------------------------------------
      SUBROUTINE  MOON (D1, D2)
      INTEGER D1, D2
C
      REAL RA, DEC, PARA
      INTEGER HOUR,DAY,Y,M,D,WD
C
C  COMPUTE EPHEMERIS AND WRITE RESULTS AT 1000 DAY INTERVALS
C
      DO 2 DAY=D1,D2
         DO 1 HOUR=0,23
            CALL MOONEF (DAY, HOUR, RA, DEC, PARA)
            IF (MOD(DAY-D1+1,1000) .EQ. 1 .AND. HOUR .EQ. 0) THEN
               CALL GREGOR(DAY,Y,M,D,WD)
               WRITE(*,'('' '',I2,''.'',I2,''.'',I4,
     .                   ''   R.A = '',F8.3,''  DEC = '',F8.3,
     .                   ''  PARALLAX = '',F8.3)')
     .               D,M,Y,RA,DEC,PARA
            ENDIF
 1       CONTINUE
 2    CONTINUE

      WRITE (*,'('' LUNAR EPHEMERIS COMPUTED FOR DN = '',
     .           I5,'' .. '',I5/)')
     .       D1, D2
      RETURN
      END
