      SUBROUTINE PUTSHF(A,YK,N,ESHIFT)
CDEP  
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      DIMENSION A(N,N),YK(N)     
C     
      CALL COPDIA(A,N,YK)
C     
      ESHIFT=1E+30
      DO 100 I=1,N
         ESHIFT=MIN(YK(I),ESHIFT)
 100  CONTINUE      
C     
      ESHIFT=ESHIFT*(1.+1E-3)
      DO 200 I=1,N
         A(I,I)=A(I,I)-ESHIFT
 200  CONTINUE
C     
      WRITE(6,1000) ESHIFT
 1000 FORMAT(1X,'**PUTSHF: ESHIFT=',1P,G20.10)
      END
