      SUBROUTINE GAUSL3 (WG,XI,NQP)
      DOUBLE PRECISION WG(*), XI(*)
      INTEGER NQP
      DOUBLE PRECISION SQ, W1, W2
      PARAMETER (SQ = 0.7745966692414834D0)
      PARAMETER (W1 = 5.D0/9.D0, W2 = 8.D0/9.D0)
      NQP = 3
      WG(1) = W1
      WG(2) = W2
      WG(3) = W1
      XI(1) = -SQ
      XI(2) = 0.D0
      XI(3) = SQ
      RETURN
      END
