      DOUBLE PRECISION FUNCTION ENORM(S0,S,NNODX)
      DOUBLE PRECISION S0(*),S(*),SUM
      INTEGER NNODX,I

      SUM=0.0D0
      DO 10 I=1,NNODX
10      SUM=SUM+DABS((S0(I)-S(I)))**2.0D0
      ENORM=DSQRT(SUM)
      RETURN
      END
