      FUNCTION CONCHK(A,X,N)
CDEP  
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      DIMENSION X(N)
      C=0.                                 
      DO 100 I=1,N
         C=MAX(C,DABS(A*X(I)))
 100  CONTINUE
      CONCHK=C
      END
