C----------------------------------------------------------------------
C
C  A S 7
C
C  INTEGRATE EQUATIONS OF MOTIONS WITH THE SEVENTH ORDER
C  ADAMS-STOERMER DIFFERENCE METHOD
C  D1 AND D2 ARE THE DAY NUMBERS OF THE FIRST AND LAST DAY TO BE WRITTEN
C  H IS THE INTEGRATION STEP IN DAYS AND OUTP IS THE INTERVAL BETWEEN
C  SUCCESSIVE OUTPUTS
C
C----------------------------------------------------------------------
      SUBROUTINE AS7 (D1, H, D2, OUTP)
      INTEGER
     .    D1,        
     .    D2         
      REAL
     .    H,         
     .    OUTP       
C
      INTEGER
     .    ITERS,
     .    INTEGS
C
      CALL INTINI
      CALL START(H, 1.0D-25, ITERS)
      CALL INTEG(D1,H,D2, OUTP, INTEGS)
      WRITE (*,'(/'' PLANETARY EPHEMERIS COMPUTED''/
     .            '' NUMBER OF INITIAL ITERATIONS '',I2/
     .            '' NUMBER OF INTEGRATION STEPS '',I5/
     .            '' TIME INTERVAL DN = '',I5,'' .. '',I5/)')
     .       ITERS, INTEGS, D1, D2
      RETURN
      END
