#!/bin/sh
# Run script for FREQUENCY
# Date generated:  Thu Dec  8 13:49:19 EET 1994
# For cypress (IRIX64 cypress 6.0 08241804 IP21 mips)
exec > FREQUENCY.out 2>&1
MP_SET_NUMTHREADS=1; export MP_SET_NUMTHREADS
MPC_NUM_THREADS=1; export MPC_NUM_THREADS
CMD=timex
echo 'FREQUENCY'
date
$CMD ./FREQUENCY.exe < FREQUENCY.in
exit $?
