      DOUBLE PRECISION FUNCTION SSUM (N,X,INCX)
      INTEGER N, INCX
      DOUBLE PRECISION X(*)
      INTEGER I, IX
      SSUM = 0.0D0
      IX = 1
      DO 100 I=1,N
         SSUM = SSUM + X(IX)
         IX = IX + INCX
 100  CONTINUE
      RETURN
      END
