      SUBROUTINE SPAXPY (N,ALFA,X,Y,INDEX)
      INTEGER N, INDEX(*)
      DOUBLE PRECISION ALFA, X(*), Y(*)
      INTEGER I, II
      DO 100 I=1,N
         II = INDEX(I)
         Y(II) = Y(II) + ALFA*X(I)
 100  CONTINUE
      RETURN
      END
