      SUBROUTINE TESTA(U,F,NX,NY,NZ,ITER,NW1)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      DIMENSION U(NX,NY,NZ), F(NX,NY,NZ)
C
        H=1./(NX-1)
        CALL INIT(U,F,NX,NY,NZ)
        RES1=RES(U,F,NX,NY,NZ,H)
C----------------> TIMER IN SECONDS
c--        CALL TIMER(SEC1)
        DO 2 NREL=1,ITER
          CALL RELAXA(U,F,NX,NY,NZ,H)
2       CONTINUE
c--        CALL TIMER(SEC2)
C----------------> TIMER IN SECONDS (IN SEC2)
        RES2=RES(U,F,NX,NY,NZ,H)
        CONVR=(RES2/RES1)**(0.1)
        WRITE(NW1,91100)
        WRITE(NW1,9100)NX,NY,NZ,NX*NY*NZ, ITER, CONVR
C
        NOP = (NX-2)*(NY-2)*(NZ-2)*8
C
c--        RMFLOP = (NOP/1000000.)/(SEC2-SEC1)*ITER
c--        WRITE(NW1,900) (SEC2-SEC1)/ITER,NOP, RMFLOP
        WRITE(NW1,91100)
91100 FORMAT(' +++++++++   STANDARD IMPLEMENTATION  ++++++++++++++++ '/
     *     )
 9100 FORMAT (/' NUMBER OF POINTS PER DIRECTION = ', 3I12 /
     *        ' GRIDSIZE OF CUBIC  GRID =        ', I12/
     *        ' AVERAGE CONV. RATE (', I6, 'ITER.)  = ', D12.4/)
900    FORMAT(/' TIME FOR 1 RELAX (SEC.):', E15.8/
     *           ' NUMBER OF OPERATIONS:   ',I15/
     *           ' PERFORMANCE IN MFLOP/S: ',F15.5/)
      END
