C     *****************
      SUBROUTINE VDRSET(SEED)
C     *****************
C
C
      DOUBLE PRECISION DRAND,DUMMY
C
C
      INTEGER   SEED
C
C
      DUMMY = DRAND(SEED)
C
C
      RETURN
      END
C
C


