C     ****************
      SUBROUTINE WLINE(
C     ****************
     >                 NVE,NXYZ,NXYZE,NT,
     >                 WLR,WLI,
     >                 LINKS,
     >                 GTS,
     >                 WK1,WK2,WK3)
C
C
      DOUBLE PRECISION LINKS(NVE,18,4),
     >                 WK1(NXYZ,18),WK2(NXYZ,18),WK3(NXYZ,18),
     >                 WLR,WLI,
     >                 THREE,ZERO
C
C
      INTEGER          GTS(NXYZ)
C
C
      PARAMETER( THREE = 3.D0 )
      PARAMETER( ZERO  = 0.D0 )
C
C
C     CALCULATE THE PRODUCT OF SU3 MATRICES IN T-DIRECTION
C
C
C     LOOP OVER TWO CHESS BOARD COLOURS
C
C
      WLR = ZERO
      WLI = ZERO
C
C
C     ***********
      CALL GATHER( NXYZ,NXYZ,WK1,NVE,LINKS(1,1,4),GTS(1),0 )
C     ***********
C
C
C     LOOP OVER NT T-SLICES
C
C
      DO 20 IT = 1,NT-1
C
C
C     ***********
      CALL GATHER( NXYZ,NXYZ,WK2,NVE,LINKS(1,1,4),GTS(1),IT * NXYZE )
C     ***********
C
C
C     ********
      CALL PRO(NXYZ,NXYZ,1,WK3,WK1,WK2)
C     ********
C
C
      DO 40 ISM = 1,18
      DO 40 ILP = 1,NXYZ
      WK1(ILP,ISM) = WK3(ILP,ISM)
   40 CONTINUE
C
C
   20 CONTINUE
C
C
C     CALCULATING THE TRACES
C
C
      DO 50 ILP = 1,NXYZ
C
      WLR = WLR + WK1(ILP, 1) + WK1(ILP, 5) + WK1(ILP, 9)
      WLI = WLI + WK1(ILP,10) + WK1(ILP,14) + WK1(ILP,18)
C
   50 CONTINUE
C
      WLR = WLR / THREE
      WLI = WLI / THREE
C
      END
