      SUBROUTINE WRITEO(B,N)
CDEP  
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      DIMENSION B(N)
      WRITE(6,*)'SOLUTION VECTOR ='
      WRITE(6,'(/1P,(10G12.4))') (B(I),I=1,N)
      WRITE(6,*)
      END      
