      SUBROUTINE MATVE2(A,B,N,AB,NC)
CDEP  
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      DIMENSION A(N,N),B(N),AB(NC)
C     
      DO 100 I=1,NC
         AB(I)=0.
 100  CONTINUE
C     
      DO 200 J=1,N
         BJ=B(J)
         DO 210 I=1,NC 
            IA=N-NC+I
            AB(I)=AB(I)+A(IA,J)*BJ
 210     CONTINUE
 200  CONTINUE
      END       
