      SUBROUTINE INIT(U,F,NX,NY,NZ)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      DOUBLE PRECISION U(NX,NY,NZ),F(NX,NY,NZ)
      DO 10 K = 1, NZ-1
        DO 20 J = 1, NY-1
          DO 30 I = 1, NX-1
            U(I,J,K) = 0.
30        CONTINUE
20      CONTINUE
10    CONTINUE
C
      DO 11 K = 2, NZ-1
        DO 21 J = 2, NY-1
          DO 31 I = 2, NX-1
            U(I,J,K) = 1000.
            F(I,J,K) = 10.
31        CONTINUE
21      CONTINUE
11    CONTINUE
C
      END
