      FUNCTION CPTIME ()
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
C
C   RETURNS THE CPU TIME SINCE THE LAST CALL TO CPTIME.
C   THIS SUBPROGRAM MAY BE CHANGED AS NEEDED FOR A PARTICULAR COMPUTER
C   SYSTEM WITHOUT PENALTY, PROVIDED IT PERFORMS THIS FUNCTION.
C
      DOUBLE PRECISION CPUTIM,TX
      EXTERNAL CPUTIM
      SAVE TX
      DATA TX/0./
      T = CPUTIM ()
      CPTIME = T - TX
      TX = T
      RETURN
      END
