      SUBROUTINE READI(INPUT,A,B,IIROW,JJCOL,N,IZ)
C..   MATRIX INPUT; BORROWED FROM INVPOWER-BENCHMARK 26.1.1991/SBS
CDEP  
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      DIMENSION A(*),B(N)
      DIMENSION IIROW(*),JJCOL(*)
C     
      IP=1
 100  CONTINUE
      IZ=IP-1
      READ(INPUT,1000,END=110) 
     +     JCOL,IROW,NTERMS,(B(I),I=1,NTERMS)
c--     +     JCOL,IROW,NTERMS,(A(I),I=IP,IP+NTERMS-1)
      DO 120 I=IP,IP+NTERMS-1
         A(I) = B(I-IP+1)
         IIROW(I)=IROW+I-IP
         JJCOL(I)=JCOL
 120  CONTINUE
      IP=IP+NTERMS
      GOTO 100
 110  CONTINUE
      DO 200 I=1,N
         B(I)=I
 200  CONTINUE
 1000 FORMAT(2I5,I3,5F13.0,:,/(6F13.0))
      END
