      SUBROUTINE SCOPY(N,X,INCX,Y,INCY)
      INTEGER N, INCX, INCY
      DOUBLE PRECISION X(*), Y(*)
      INTEGER I, IX, IY
      IX = 1
      IY = 1
      DO 100 I=1,N
         Y(IY) = X(IX)
         IX = IX + INCX
         IY = IY + INCY
 100  CONTINUE
      RETURN
      END
