      SUBROUTINE MODIF (MA,A,NODEL)
      INTEGER NODEL
      DOUBLE PRECISION A(*),MA(2,2*NODEL)
      DOUBLE PRECISION ZERO
      PARAMETER (ZERO=0.D0)
      INTEGER DOFEL, J
      DOFEL = 2*NODEL
      CALL VFILL (2*DOFEL,MA,ZERO)
      DO 300 J=1,NODEL
         MA(1,2*J-1)= A(J)
         MA(2,2*J)= A(J)
300   CONTINUE     
      RETURN
      END
