C     *****************
      SUBROUTINE SCATER(NVH3,NVL,WK3,NVH2,WK2,IW1,IWOSET)
C     *****************

C     SPECIAL PURPOSE SCATTER ROUTINE FOR SU3 LATTICE GAUGE THEORY
C     FUNCTION: WK3( IW1(1:NVL) + IWOSET, 1:18 ) = WK2( 1:NVL, 1:18 )

      INTEGER           IW1(  NVH2       )
      DOUBLE PRECISION  WK3(  NVH3,   18 ) , WK2( NVH2, 18 ) 


      DO 10 ISM = 1,18
      DO 20 IVL = 1,NVL
      WK3( IW1(IVL) + IWOSET, ISM ) = WK2( IVL, ISM )
   20 CONTINUE
   10 CONTINUE


        END
