      SUBROUTINE CLUSTR(JDIM,YMAX,YMIN,DYM,LMAX,R)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      DIMENSION R(JDIM)
C
C
C
      EPS = EPSIL(YMAX,YMIN,DYM,LMAX,0.001,100,1,2)
      K = -1
      R(1) = YMIN
      DO 5 L = 2,LMAX
      K = K+1
      GN = (1.0 +EPS/SQRT(FLOAT(K+4)))**K
      R(L) = R(L-1)+DYM*GN
    5 CONTINUE
C
      RETURN
      END
