      SUBROUTINE DIRECT (NELE,ELTOP,IELTOP,STEER)
      INTEGER NELE, IELTOP, ELTOP(IELTOP,*),STEER(*)
      INTEGER I

      DO 10 I=1,ELTOP(2,NELE)
         STEER(I) = ELTOP(2+I,NELE)
 10   CONTINUE
      RETURN
      END 
