      SUBROUTINE SCALET

      IMPLICIT CHARACTER ( A-Z )

      COMMON/VELOC/VX,VY,VZ
      COMMON/TEMPER/EQTEMP
      COMMON/ENERGY/V,K,W
      COMMON/ATOMS/NATM

      INTEGER     NMAX
      PARAMETER ( NMAX = 60000 )

      REAL         VX(NMAX), VY(NMAX), VZ(NMAX)
      REAL         EQTEMP,V,K,W
      REAL         SCALEF

      INTEGER      NATM, I

      SCALEF = SQRT(EQTEMP/(2.0*K/(3.0*REAL(NATM-1))))

C**   SCALE VELOCITIES

      DO 10 I = 1,NATM
        VX(I) = VX(I)*SCALEF
        VY(I) = VY(I)*SCALEF
        VZ(I) = VZ(I)*SCALEF
 10     CONTINUE

      RETURN
      END
