      SUBROUTINE PUTSCR(IUN,A,N,M,IREW)
CDEP  
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
c--      DIMENSION A(N,M),atmp(n,m)
      DIMENSION A(N,M)

c--version 3
      IF (IREW.EQ.1) REWIND IUN
      DO 100 J=1,M
         WRITE(IUN) (A(I,J),I=1,N)
 100  CONTINUE
c--      do 100 j=1,m
c--         do 110 i=1,n
c--            atmp(i,j)=a(i,j)
c-- 110     continue
c-- 100  continue
      END
