      SUBROUTINE EMITST (ER, FP, TM)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
C
C   EMIT TEST SUBROUTINE
C
      PARAMETER (NW=100, NB=5, NV=1000, NVM=1500, F7=78125.,
     $ T30=1073741824.)
      COMPLEX Z, WALL, ZCR, REFPT,  EXPWKL, EXPMWK, FORCE,
     & UUPSTR, DUM3, EXPZ, EXPMZ
      COMMON /ARRAYS/ NWALL(NB), IALIGN,
     $     WALL(NW,NB), RMATRX(NW*NB,NW*NB),
     $ ZCR(NW,NB), Z(NVM), GAMMA(NVM), REFPT(NB), RHS(NW*NB),
     $ FORCE(NB), RMOM(NB), CP(NW,NB), DPDS(NW,NB), EXPZ(NVM),
     $ EXPMZ(NVM), PSI(NW), PS(NVM)
      DATA IT/10/, ANS/6.0088546832072/
C
      T2 = F7 / T30
      DO 100 J = 1, NB
        NWALL(J) = NW
        REFPT(J) = 0.
        FORCE(J) = 0.
        RMOM(J) = 0.
        DO 100 I = 1, NW
          T1 = MOD (F7 * T2, 1.0D0)
          T2 = MOD (F7 * T1, 1.0D0)
          WALL(I,J) = CMPLX (T1, T2)
          T1 = MOD (F7 * T2, 1.0D0)
          T2 = MOD (F7 * T1, 1.0D0)
          ZCR(I,J) = CMPLX (T1, T2)
          DPDS(I,J) = 0.
100   CONTINUE
      DO 110 J = 1, NW*NB
        RMATRX(J,J) = 1.
        DO 110 I = 1, J-1
          T2 = MOD (F7 * T2, 1.0D0)
          RMATRX(I,J) = .001 * T2
          RMATRX(J,I) = .001 * T2
110   CONTINUE
      DO 120 I = 1, NVM
        T1 = MOD (F7 * T2, 1.0D0)
        T2 = MOD (F7 * T1, 1.0D0)
        Z(I) = CMPLX (T1, T2)
        T2 = MOD (F7 * T2, 1.0D0)
        GAMMA(I) = T2
120   CONTINUE
      TM = CPTIME ()
C
C   TIMING TEST
C
      DO 130 I = 1, IT
        CALL EMIT
130   CONTINUE
C
      TM = CPTIME ()
      ER = ABS ((RHS(19) - ANS) / ANS)
      FP = IT * (56.*NV + NB*NW * (97. + 44.*NV + 2.*NB*NW))
C
      RETURN
      END
