      SUBROUTINE GMTTST (ER, FP, TM)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
C
      PARAMETER (NW=100, NB=5, F7=78125., T30=1073741824.)
      COMPLEX WALL, ZCR, PROJ, ZI, Z1, ZZ
      COMMON /ARRAYS/ NWALL(NB), IALIGN,
     $     WALL(NW,NB), RMATRX(NW*NB,NW*NB),
     $ ZCR(NW,NB), PROJ(NW,NB), XMAX(NB)
      DATA IT/2/, ANS/-2.57754233214174/
C
C   INITIALIZATION
C
      LW = 2 * NW * NB
      T2 = F7 / T30
      DO 100 J = 1, NB
        NWALL(J) = NW
100   CONTINUE
      DO 110 J = 1, NB
        DO 110 I = 1, NW
          T1 = MOD (F7 * T2, 1.0D0)
          T2 = MOD (F7 * T1, 1.0D0)
          WALL(I,J) = CMPLX (T1, T2)
110   CONTINUE
      TM = CPTIME ()
C
C   TIMING TEST
C
      DO 120 I = 1, IT
        CALL GMTRY
120   CONTINUE
C
      TM = CPTIME ()
      ER = ABS ((RMATRX(19,19) - ANS) / ANS)
      FP = IT * (120. * (NB*NW) ** 2  +  0.666 * (NB*NW) ** 3)
C
      RETURN
      END
