      PARAMETER (MMAX=7,MAXIT=50)
C---> USER SUPPLIED PARAMETER:
C
C     DEFINITION OF FINEST GRIDSIZE: (2**MMAX+1)**3
C
C     RESULTS ARE OBTAINED FOR THE FINEST GRID RANGING FROM 3 TO MMAX.
C     MMAX SHOULD BE CHOSEN AS LARGE AS POSSIBLE, DEPENDING ON MEMORY
C     CAPACITIES OF THE MACHINE.
C
C     DEFINITION OF MAXIMAL NUMBER OF ITERATIONS
C
C     USED TO GET A LARGER TIMING INTERVAL FOR SMALL PROBLEMS. THE
C     NUMBER OF ITERATIONS FOR LARGER PROBLEMS IS AT LEAST 5.
C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
