C     ***************
      SUBROUTINE HEAD(
C     ***************
     >                NS,NT,NW1,
     >                START,IAVG,IAVGDD,SEED,ITEMAX,
     >                METHIT,ITBLUP,ORDEXP,BETA,SIGMA )
C
C
C     SUBROUTINE HEAD PRINTS THE HEADING OF THE OUTPUT FILE
C
C
C     REVISION - NOV. 1989; E.KEHL
C
C     LATEST REVISION - April, 1992, V.Getov
C
      DOUBLE PRECISION    BETA,SIGMA
C
C
      INTEGER  ORDEXP,SEED,START
C
C
      CHARACTER*10 PST(0:1)
C
C
      DATA PST /'DISORDERED',
     >          '   ORDERED'/
      CALL HEADER(NW1)
C
C
      WRITE( NW1, 1010)
      WRITE( NW1, 1020) NS,NT
      WRITE( NW1, 1040) PST(START)
      WRITE( NW1, 1050) ITEMAX
      WRITE( NW1, 1055) METHIT
      WRITE( NW1, 1060) IAVGDD
      WRITE( NW1, 1070) IAVG
      WRITE( NW1, 1080) SEED
      WRITE( NW1, 1090) ITBLUP
      WRITE( NW1, 1100) SIGMA
      WRITE( NW1, 1110) BETA
C
      WRITE( NW1, 1120)
C
C
 1010 FORMAT(2(/),10X,
     >'INPUT PARAMETERS:'/10X,
     >'---------------- '     )
C
 1020 FORMAT(//10X,
     >'Lattice Size                            :'
     >,I3,' CUBED TIMES ',I3)
C
 1040 FORMAT(10X,
     >'Start Configuration                     :',9X,A10)
C
 1050 FORMAT(10X,
     >'Total Number of Iterations              :',9X,I10)
C
 1055 FORMAT(10X,
     >'Number of Metropolis-hits               :',9X,I10)
C
 1060 FORMAT(10X,
     >'Discarded Iterations for Thermalization :',9X,I10)
C
 1070 FORMAT(10X,
     >'Modul for Taking Averages               :',9X,I10)
C
 1080 FORMAT(10X,
     >'Start Value of Random Number Generator  :',9X,I10)
C
 1090 FORMAT(10X,
     >'SU3 Matrix Table Update Modul           :',9X,I10)
C
 1100 FORMAT(10X,
     >'Standard Deviation of Gaussian Rand. NO.:',4X,E15.6)
C
 1110 FORMAT(10X,
     >'Bare Coupling Constant                  :',4X,E15.6)
C
 1120 FORMAT(2(/),10X,
     >'RESULTS:'/10X,
     >'------- '     )
C
C
      END
