C     ****************
      SUBROUTINE SRLKS(
C     ****************
     >                 LINKS,NVE,
     >                 G,N,ISD,IRD,
     >                 L,WK1,
     >                 ICC,ILD )
C
C
      DOUBLE PRECISION LINKS(NVE,18,4),
     >                 WK1  (N  ,18  )
C
C
      INTEGER   G(N,2,4),L(2,4)
C
C
      ISN = ISD
      IF( IRD .EQ. 3 ) IRN = 2
      IF( IRD .EQ. 4 ) IRN = 1
      NS = L(ICC,ISD)
      NR = L(ICC,IRD)
C
C
C     ***********
      CALL GATHER( N,NS,WK1,NVE,LINKS(1,1,ILD),G(1,ICC,ISD),0 )
C     ***********
C
C     ***********
      CALL SCATER( NVE,NR,LINKS(1,1,ILD),N,WK1,G(1,ICC,IRD),0 )
C     ***********
C
      END
