      SUBROUTINE READI(FII,FREQR,XSIIR,NDIM,NMODES)
CDEP  
      IMPLICIT REAL (A-H,O-Z)
      DIMENSION FII(NDIM,NMODES),FREQR(NMODES),XSIIR(NMODES)
C     
 1000 FORMAT(5X,'MODE: ',I3,' FREQUENCY=',1P,G13.5,' DAMPING=',G13.5)
C     
      DO 200 I=1,NMODES
         READ(1,*) K,FREQ,XSII
         WRITE(6,1000) K,FREQ,XSII
         FREQR(K)=FREQ
         XSIIR(K)=XSII
         READ(1,'((6F13.0))') (FII(J,K),J=1,NDIM)
 200  CONTINUE
      END   
