      SUBROUTINE GAUSQ4 (WG,XI,ETA,NQP)
      DOUBLE PRECISION WG(*), XI(*), ETA(*)
      INTEGER NQP
      DOUBLE PRECISION SQ
      PARAMETER (SQ = 0.5773502691896256D0)
      NQP = 4
      WG(1) = 1.D0
      WG(2) = 1.D0
      WG(3) = 1.D0
      WG(4) = 1.D0
      XI(1)  = SQ
      ETA(1) = SQ
      XI(2)  = -SQ
      ETA(2) = SQ
      XI(3)  = -SQ
      ETA(3) = -SQ
      XI(4)  = SQ
      ETA(4) = -SQ
      RETURN
      END
