      SUBROUTINE TRANSP(A,N,AT)
CDEP  
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      DIMENSION A(N,N),AT(N,N)
      N1=N-1
      DO 100 J=1,N1
         DO 110 I=J+1,N
            AT(J,I)=A(I,J)
 110     CONTINUE
 100  CONTINUE
      END       
