      SUBROUTINE SPECT(JDIM,KDIM,UU,VV,CCX,CCY,XYJ,XY,SPECTX,SPECTY)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
C
C
C  FORM SPECTX AND SPECTY INDEPENDENTLY
C
C     SPECTX = (ABS(UU) + CCX)/XYJ
C     SPECTY = (ABS(VV) + CCY)/XYJ
C
      COMMON/BASE/
     1  JMAX,       KMAX,     JM,          KM,          JBEGIN,   JEND,
     1  KBEGIN,     KEND,     JPLUS(999),  JMINU (999), JLOW,     JUP,
     1  KLOW,       KUP,      PERIDC  ,    NP,          DT,   CP2TIM,
     1  FSMACH,     ALPHA,    GAMMA,       GAMI,        PI,
     1  DIS2X,      DIS2Y,    DIS4X,       DIS4Y,       PHIDT,    
     1  THETAD ,    RESID,    JACDT,       IPRINT,      NPCP,
     1  JTAIL1,     JTAIL2,   NUMITE ,     ISTART,      NSTEPS
      LOGICAL PERIDC  
      COMMON/GRID/DYM,YMAX,XMIN,XMAX,THICK
C
      DIMENSION XYJ(JDIM,KDIM),XY(JDIM,KDIM,4)
      DIMENSION SPECTX(JDIM,KDIM),UU(JDIM,KDIM),CCX(JDIM,KDIM)
      DIMENSION SPECTY(JDIM,KDIM),VV(JDIM,KDIM),CCY(JDIM,KDIM)
C
C   COMPUTE DISSIPATION SCALING
C
C
C  SPECTRAL RADIUS
C
           DO 100 K=KBEGIN,KEND
           DO 100 J=JBEGIN,JEND
C
           SIGX = ABS(UU(J,K)) + CCX(J,K)
           SIGY = ABS(VV(J,K)) + CCY(J,K)
C
           RJ = 1./XYJ(J,K)
           SPECTX(J,K) = SIGX*RJ
           SPECTY(J,K) = SIGY*RJ
C
100        CONTINUE
C
                RETURN
                END
